﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;

namespace ControlContainerEditor_CS
{
    public partial class DifferentEditAndRenderForm : Form
    {
        #region Constructor

        public DifferentEditAndRenderForm()
        {
            InitializeComponent();
        }
        #endregion //Constructor

        #region Event Handlers

        #region ultraGrid1_AfterCellUpdate

        private void ultraGrid1_AfterCellUpdate(object sender, CellEventArgs e)
        {
            UltraGridRow row = e.Cell.Row;
            if (e.Cell.Column.Key == "Grades" && !row.InInitializeRowEvent)
            {
                List<Grades> gradeList = e.Cell.Value as List<Grades>;
                if (gradeList != null)
                {
                    // Copy the values back to the bound columns so that they could
                    // be persisted to, for example, a database.
                    Grades grades = gradeList[0];
                    row.Cells["Fall"].Value = grades.Fall;
                    row.Cells["Winter"].Value = grades.Winter;
                    row.Cells["Spring"].Value = grades.Spring;
                }
            }
        }
        #endregion //ultraGrid1_AfterCellUpdate

        #region ultraGrid1_InitializeLayout

        private void ultraGrid1_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            UltraGridBand band = e.Layout.Bands[0];

            // Create an unbound column that will be used to display and edit the three different
            // trimester grades for each student.
            UltraGridColumn gridColumn = band.Columns.Add("Grades");
            gridColumn.DataType = typeof(List<Grades>);
            gridColumn.EditorComponent = this.ultraControlContainerEditor1;
            gridColumn.Width = 240;

            e.Layout.Override.DefaultRowHeight = 85;

            // Hide the bound columns, since we're going to be using the new unbound column
            // for both displaying and editing these values       
            band.Columns["Fall"].Hidden = true;
            band.Columns["Winter"].Hidden = true;
            band.Columns["Spring"].Hidden = true;
        }
        #endregion //ultraGrid1_InitializeLayout

        #region ultraGrid1_InitializeRow

        private void ultraGrid1_InitializeRow(object sender, InitializeRowEventArgs e)
        {
            if (!e.ReInitialize)
            {
                // When we're first initializing the row, we need to create a new object in
                // the unbound column that is going to use the UltraControlContainerEditor
                Grades grades = new Grades();
                grades.Fall = (double)e.Row.GetCellValue("Fall");
                grades.Winter = (double)e.Row.GetCellValue("Winter");
                grades.Spring = (double)e.Row.GetCellValue("Spring");

                // The chart needs an IList to display data, so put the grades information into one
                e.Row.Cells["Grades"].Value = new List<Grades>(new Grades[] { grades });
            }
        }
        #endregion //ultraGrid1_InitializeRow

        #endregion //Event Handlers
    }
}
