﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinEditors;

namespace ControlContainerEditor_CS
{
    public partial class GradeEditorUC : UserControl
    {
        #region Members

        private List<Grades> cachedGrades;

        #endregion //Members

        #region Constructor

        public GradeEditorUC()
        {
            InitializeComponent();
        }
        #endregion //Constructor

        #region Events

        public event EventHandler GradesChanged;

        #endregion //Events

        #region Properties

        #region Grades

        [Browsable(false)]        
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public List<Grades> Grades
        {
            get 
            {
                // Store a cached instance of the list.  The reason that we need to store a cached
                // instance of this list is because the grid determines whether an object has changed
                // based on that particular instance, not any sub-objects of that instance.  For example,
                // if the grid value is an integer, the grid knows that the value changes simply by determining
                // if the values are not equal, marking the row as dirty accordingly.  In the case of having 
                // a class instance in the cell (such as we do here), if we kept the same instance of the class
                // around through all the changes, the grid would always see that we still have the same object
                // in the cell, since it doesn't know about the sub objects.  When the grid sees the same objects, 
                // it does not mark the row as dirty and will not fire the various update-related events; furthermore,
                // actions like pressing Esc will not work because the grid does not have a different value to assign
                // back to the cell.  We work around all this behavior by returning a new list object when any of the
                // values have been changed.
                if(this.cachedGrades != null)
                    return this.cachedGrades;

                Grades grades = new Grades();
                grades.Fall = (double)this.uneFall.Value;
                grades.Winter = (double)this.uneWinter.Value;
                grades.Spring = (double)this.uneSpring.Value;
                grades.PropertyChanged += new PropertyChangedEventHandler(GradeEditorUC_PropertyChanged);

                this.cachedGrades = new List<Grades>();
                this.cachedGrades.Add(grades);

                return this.cachedGrades;
            }
            set
            {
                if (this.cachedGrades == value)
                    return;

                if(this.cachedGrades != null && this.cachedGrades.Count == 1)
                    this.cachedGrades[0].PropertyChanged -= new PropertyChangedEventHandler(GradeEditorUC_PropertyChanged);

                this.cachedGrades = value;

                if (this.cachedGrades != null && this.cachedGrades.Count == 1)
                    this.cachedGrades[0].PropertyChanged += new PropertyChangedEventHandler(GradeEditorUC_PropertyChanged);

                this.UpdateUI();
            }
        }
        #endregion //Grades

        #endregion //Properties

        #region Methods

        #region FireGradesChanged

        private void FireGradesChanged()
        {
            // Clear out the cached grades list so that we re-create it the next
            // time that it's requested.  See the comments in the Grades property
            // for the reason we are caching this property and recreating it on changes.
            if (this.cachedGrades != null && this.cachedGrades.Count == 1)
                this.cachedGrades[0].PropertyChanged -= new PropertyChangedEventHandler(GradeEditorUC_PropertyChanged);
            //
            this.cachedGrades = null;

            if (this.GradesChanged != null)
                this.GradesChanged(this, EventArgs.Empty);
        }
        #endregion //FireGradesChanged

        #region UpdateUI

        private void UpdateUI()
        {
            if (this.cachedGrades == null)
                this.uneFall.Value = this.uneWinter.Value = this.uneSpring.Value = null;
            else
            {
                Grades grades = this.Grades[0];
                this.uneFall.Value = grades.Fall;
                this.uneSpring.Value = grades.Spring;
                this.uneWinter.Value = grades.Winter;
            }
        }
        #endregion //UpdateUI

        #endregion //Methods

        #region Event Handlers

        #region GradeEditorUC_PropertyChanged

        void GradeEditorUC_PropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            this.FireGradesChanged();
        }
        #endregion //GradeEditorUC_PropertyChanged

        #region une_ValueChanged

        private void une_ValueChanged(object sender, EventArgs e)
        {
            this.FireGradesChanged();
        }
        #endregion //une_ValueChanged

        #endregion //Event Handlers
    }
}
