﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

namespace ControlContainerEditor_CS
{
    public partial class DateTimeUC : UserControl
    {
        #region Members

        private Nullable<DateTime> cachedDate;

        #endregion //Members

        #region Constructor

        public DateTimeUC()
        {
            InitializeComponent();
        }
        #endregion //Constructor

        #region Events

        /// <summary>
        /// Fired when the Date property is changed.  This is necessary so that the UltraControlContainerEditor knows
        /// when the property has changed and the owner's value should be changed.
        /// </summary>
        public event EventHandler DateChanged;

        #endregion //Events

        #region Properties

        #region Date

        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public DateTime Date
        {
            get
            {
                // So that we don't have to create a new object every time that this property is requested, 
                // keep a cached version.  This will be cleared whenever we update the value so that it can be
                // regenerated later.
                if (this.cachedDate.HasValue)
                    return this.cachedDate.Value;

                // Create a new DateTime object based on the values of the two editors
                DateTime date = this.dteDate.DateTime;
                DateTime time = this.umeTime.Value != null ? (DateTime)this.umeTime.Value : DateTime.Today;

                this.cachedDate = new DateTime(date.Year, date.Month, date.Day, time.Hour, time.Minute, time.Second);
                return this.cachedDate.Value;
            }
            set
            {
                this.dteDate.Value = value;
                this.umeTime.Value = value;
            }
        }
        #endregion //Date

        #endregion //Properties

        #region Event Handlers

        #region DateValueChanged

        private void DateValueChanged(object sender, EventArgs e)
        {
            // Clear the cache so that we update it later when it is needed
            this.cachedDate = null;

            // Notify any listeners that the Date property has changed.  We will likely
            // recreate the cached value when the listener asks for it
            if (this.DateChanged != null)
                this.DateChanged(this, EventArgs.Empty);
        }
        #endregion //DateValueChanged

        #endregion //Event Handlers
    }
}
