﻿using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;

namespace ControlContainerEditor_CS
{
    public class Address 
        : INotifyPropertyChanged
    {
        #region Private Members
        
        private string streetAddress;
        private string city;
        private string state;
        private string zip;
        private bool ok;

        private PropertyChangedEventHandler propertyChangedDelegate;

        #endregion //Private Members

        #region Constructor

        public Address(string streetAddress,
            string city,
            string state,
            string zip, 
            bool ok)
        {
            this.streetAddress = streetAddress;
            this.city = city;
            this.state = state;
            this.zip = zip;
            this.ok = ok;
        }

        #endregion //Constructor

        #region Public Properties

        public string StreetAddress
        {
            get { return streetAddress; }
            set 
            {
                if (string.Compare(this.streetAddress, value, false) == 0)
                    return;

                this.streetAddress = value;

                if (this.propertyChangedDelegate != null)
                    this.propertyChangedDelegate(this, new PropertyChangedEventArgs("StreetAddress"));
            }
        }

        public string City
        {
            get { return city; }
            set
            {
                if (string.Compare(this.city, value, false) == 0)
                    return;

                this.city = value;

                if (this.propertyChangedDelegate != null)
                    this.propertyChangedDelegate(this, new PropertyChangedEventArgs("City"));
            }

        }

        public string State
        {
            get { return state; }
            set
            {
                if (string.Compare(this.state, value, false) == 0)
                    return;

                state = value;

                if (this.propertyChangedDelegate != null)
                    this.propertyChangedDelegate(this, new PropertyChangedEventArgs("State"));
            }

        }

        public string Zip
        {
            get { return zip; }
            set
            {
                if (string.Compare(this.zip, value, false) == 0)
                    return;

                this.zip= value;

                if (this.propertyChangedDelegate != null)
                    this.propertyChangedDelegate(this, new PropertyChangedEventArgs("Zip"));
            }

        }

        public bool Ok
        {
            get { return ok; }
            set
            {
                this.ok = value;

                if (this.propertyChangedDelegate != null)
                    this.propertyChangedDelegate(this, new PropertyChangedEventArgs("Ok"));
            }

        }

        #endregion //Public Properties

        #region INotifyPropertyChanged Members
       
        public event PropertyChangedEventHandler PropertyChanged
        {
            add
            {
                if (this.propertyChangedDelegate == null)
                    this.propertyChangedDelegate = value;
                else
                    this.propertyChangedDelegate = (PropertyChangedEventHandler)System.Delegate.Combine(this.propertyChangedDelegate, value);
            }
            remove
            {
                if (this.propertyChangedDelegate != null)
                    this.propertyChangedDelegate = (PropertyChangedEventHandler)System.Delegate.Remove(this.propertyChangedDelegate, value);
            }
        }

        #endregion
    }
}
